@@ -6,16 +6,15 @@
 from typing import Any
 
 from doctr import is_tf_available
-from .core import RecognitionPredictor
-from ..preprocessor import PreProcessor
+from .predictor import RecognitionPredictor
+from doctr.models.preprocessor import PreProcessor
 from .. import recognition
 
 
 __all__ = ["recognition_predictor"]
 
 
-ARCHS = ['crnn_vgg16_bn', 'crnn_resnet31', 'crnn_mobilenet_v3_small', 'crnn_mobilenet_v3_large',
-         'sar_vgg16_bn', 'sar_resnet31', 'master']
+ARCHS = ['crnn_vgg16_bn', 'crnn_mobilenet_v3_small', 'crnn_mobilenet_v3_large', 'sar_resnet31', 'master']
 
 
 def _predictor(arch: str, pretrained: bool, **kwargs: Any) -> RecognitionPredictor:
@@ -47,7 +46,7 @@ def recognition_predictor(arch: str = 'crnn_vgg16_bn', pretrained: bool = False,
         >>> out = model([input_page])
 
     Args:
-        arch: name of the architecture to use ('crnn_vgg16_bn', 'crnn_resnet31', 'sar_vgg16_bn', 'sar_resnet31')
+        arch: name of the architecture to use (e.g. 'crnn_vgg16_bn')
         pretrained: If True, returns a model pre-trained on our text recognition dataset
 
     Returns:
